@@ -73,10 +73,13 @@ class CensusDataFrame(pd.DataFrame):
         if isinstance(self, pd.MultiIndex):
             return self
 
-        if drop_geo:
-            df = pd.DataFrame(self.drop(columns=self.geo_cols))
-        else:
-            df = pd.DataFrame(self.set_index(self.geo_cols, append=True))
+        try:
+            if drop_geo:
+                df = pd.DataFrame(self.drop(columns=self.geo_cols))
+            else:
+                df = pd.DataFrame(self.set_index(self.geo_cols, append=True))
+        except KeyError: # no geo columns
+            df = self.copy()
 
         def split_col(c):
             import re
@@ -289,7 +292,7 @@ class CensusDataFrame(pd.DataFrame):
         * a string that can be resolved to a colum with .lookup()
         * A tuple of names that resolve with .lookup()
 
-        In the tuple form, the first entry is the estimate and the second is the 90% margin
+        In the tuple form, the first entry is the estimate and the second is the 90age margin
 
         :param n: The Numerator, a string, CensusSeries or tuple
         :param d: The Denominator, a string, CensusSeries or tuple
